@@ -1,8 +1,15 @@
+# see mstone_Palettes at https://github.com/mcstone/mstone/tree/5acd4ad14246feb07f759053c0e53dc2e023302e/Palettes
+
 #' Color Palettes based on Tableau (discrete)
 #'
 #' Color palettes used in
 #' \href{http://www.tableausoftware.com/}{Tableau}.
 #'
+#' The number in some palette names indicates the maximum number of
+#' values supported, e.g \code{tableau20} supports up to 20 values.
+#' \code{"trafficlight"} supports up to nine values, and \code{"cyclic"}
+#' supports up to 20 values.
+#'
 #' @export
 #' @param palette Palette name.
 #'
@@ -23,7 +30,8 @@
 #' @example inst/examples/ex-tableau_color_pal.R
 tableau_color_pal <- function(palette = "tableau10") {
   palettelist <- ggthemes_data$tableau$colors
-  if (!palette %in% c(names(palettelist), "tableau10", "tableau10light", "purplegray6", "bluered6", "greenorange6")) {
+  if (!palette %in% c(names(palettelist), "tableau10", "tableau10light",
+                      "purplegray6", "bluered6", "greenorange6")) {
     stop(sprintf("%s is not a valid palette name", palette))
   }
   if (palette == "tableau10") {
@@ -211,3 +219,36 @@ scale_fill_gradient2_tableau <- function(palette = "Red-Blue",
 #' @export
 #' @rdname scale_colour_gradient2_tableau
 scale_color_gradient2_tableau <- scale_colour_gradient2_tableau
+
+# Tableau 10 has 30 palettes
+#
+# - tableau 10
+# - tableau 20
+# - color blind
+# - seattle grays
+# - traffic light
+# - superfishel stone
+# - miller stone
+# - nuriel stone
+# - jewel bright
+# - summer
+# - winter
+# - green-orange-teal
+# - blue-red-brown
+# - purple-pink-gray
+# - tableau classic 10
+# - tableau classic medium
+# - tableau classic 20
+# - blue
+# - orange
+# - green
+# - red
+# - purple
+# - brown
+# - gray
+# - gray warm
+# - blue-teal
+# - orange-gold
+# - green-gold
+# - red-gold
+# - hue circle
