@@ -1,9 +1,3 @@
-###   scale_color_gradient_tableau scale_color_continuous_tableau
-###   scale_fill_continuous_tableau
-
-
-#'
-library("ggplot2")
 library("ggplot2")
 
 df <- data.frame(
@@ -13,7 +7,6 @@ df <- data.frame(
   z2 = abs(rnorm(100))
 )
 
-
 p <- ggplot(df, aes(x, y)) +
      geom_point(aes(colour = z2)) +
      theme_igray()
@@ -21,6 +14,3 @@ p <- ggplot(df, aes(x, y)) +
 p + scale_colour_gradient_tableau("Red")
 p + scale_colour_gradient_tableau("Blue")
 p + scale_colour_gradient_tableau("Green")
-
-
-
